@@ -273,7 +273,7 @@ def csv_last_modified(path):
 def table_outdated(conn, path):
     csv_modified = csv_last_modified(path)
 
-    if table_exists(conn, "[.csvs-meta]"):
+    if table_exists(conn, ".csvs-meta"):
         csv_meta_entry = conn.execute(
             """
             select * from [.csvs-meta]
@@ -281,20 +281,18 @@ def table_outdated(conn, path):
         """, [path]).fetchone()
         if csv_meta_entry is None:
             return True
-        return csv_modified != csv_meta_entry['last_modified']
+        return csv_modified != csv_meta_entry[1]
     return True
 
 
 def update_csvs_meta(conn, path):
-    if not table_exists(conn, "[.csvs-meta]"):
-        conn.execute("CREATE TABLE [.csvs-meta] (csv_path, last_modified)")
+    conn.execute("CREATE TABLE IF NOT EXISTS [.csvs-meta] (csv_path TEXT PRIMARY KEY, last_modified INTEGER)")
 
     csv_modified = csv_last_modified(path)
     conn.execute(
         """
-        INSERT INTO [.csvs-meta] values (?, ?)
-        ON CONFLICT(csv_path)
-        DO UPDATE SET last_modified=excluded.last_modified;
+        INSERT INTO [.csvs-meta](csv_path, last_modified) VALUES (?, ?)
+        ON CONFLICT(csv_path) DO UPDATE SET last_modified=excluded.last_modified;
     """, [path, csv_modified])
 
 
